diff mbox series

net: bnx2x: Fix spelling mistake "tupple" -> "tuple"

Message ID 20221004163235.157485-1-colin.i.king@gmail.com (mailing list archive)
State Changes Requested
Delegated to: Netdev Maintainers
Headers show
Series net: bnx2x: Fix spelling mistake "tupple" -> "tuple" | expand

Checks

Context Check Description
netdev/tree_selection success Not a local patch

Commit Message

Colin Ian King Oct. 4, 2022, 4:32 p.m. UTC
There are several spelling mistakes of tuple in comments and messages.
Fix them.

Signed-off-by: Colin Ian King <colin.i.king@gmail.com>
---
 drivers/net/ethernet/broadcom/bnx2x/bnx2x_ethtool.c | 10 +++++-----
 fs/freevxfs/vxfs_olt.c                              |  2 +-
 2 files changed, 6 insertions(+), 6 deletions(-)

Comments

Jakub Kicinski Oct. 6, 2022, 3:33 a.m. UTC | #1
On Tue,  4 Oct 2022 17:32:35 +0100 Colin Ian King wrote:
>  drivers/net/ethernet/broadcom/bnx2x/bnx2x_ethtool.c | 10 +++++-----
>  fs/freevxfs/vxfs_olt.c                              |  2 +-

Looks like two unrelated subsystems?

Please repost the netdev bits after the merge window.
diff --git a/fs/freevxfs/vxfs_olt.c b/fs/freevxfs/vxfs_olt.c
index 23f35187c289..48027a421fa3 100644
--- a/fs/freevxfs/vxfs_olt.c
+++ b/fs/freevxfs/vxfs_olt.c
@@ -63,7 +63,7 @@  vxfs_read_olt(struct super_block *sbp, u_long bsize)
 
 	op = (struct vxfs_olt *)bp->b_data;
 	if (fs32_to_cpu(infp, op->olt_magic) != VXFS_OLT_MAGIC) {
-		printk(KERN_NOTICE "vxfs: ivalid olt magic number\n");
+		printk(KERN_NOTICE "vxfs: invalid olt magic number\n");
 		goto fail;
 	}
diff mbox series

Patch

diff --git a/drivers/net/ethernet/broadcom/bnx2x/bnx2x_ethtool.c b/drivers/net/ethernet/broadcom/bnx2x/bnx2x_ethtool.c
index bda3ccc28eca..49f2a0b45b20 100644
--- a/drivers/net/ethernet/broadcom/bnx2x/bnx2x_ethtool.c
+++ b/drivers/net/ethernet/broadcom/bnx2x/bnx2x_ethtool.c
@@ -3388,7 +3388,7 @@  static int bnx2x_set_rss_flags(struct bnx2x *bp, struct ethtool_rxnfc *info)
 	switch (info->flow_type) {
 	case TCP_V4_FLOW:
 	case TCP_V6_FLOW:
 		/* For TCP only 4-tupple hash is supported */
 		if (info->data ^ (RXH_IP_SRC | RXH_IP_DST |
 				  RXH_L4_B_0_1 | RXH_L4_B_2_3)) {
 			DP(BNX2X_MSG_ETHTOOL,
@@ -3399,7 +3399,7 @@  static int bnx2x_set_rss_flags(struct bnx2x *bp, struct ethtool_rxnfc *info)
 
 	case UDP_V4_FLOW:
 	case UDP_V6_FLOW:
 		/* For UDP either 2-tupple hash or 4-tupple hash is supported */
 		if (info->data == (RXH_IP_SRC | RXH_IP_DST |
 				   RXH_L4_B_0_1 | RXH_L4_B_2_3))
 			udp_rss_requested = 1;
@@ -3418,7 +3418,7 @@  static int bnx2x_set_rss_flags(struct bnx2x *bp, struct ethtool_rxnfc *info)
 		    (bp->rss_conf_obj.udp_rss_v4 != udp_rss_requested)) {
 			bp->rss_conf_obj.udp_rss_v4 = udp_rss_requested;
 			DP(BNX2X_MSG_ETHTOOL,
-			   "rss re-configured, UDP 4-tupple %s\n",
+			   "rss re-configured, UDP 4-tuple %s\n",
 			   udp_rss_requested ? "enabled" : "disabled");
 			if (bp->state == BNX2X_STATE_OPEN)
 				return bnx2x_rss(bp, &bp->rss_conf_obj, false,
@@ -3427,7 +3427,7 @@  static int bnx2x_set_rss_flags(struct bnx2x *bp, struct ethtool_rxnfc *info)
 			   (bp->rss_conf_obj.udp_rss_v6 != udp_rss_requested)) {
 			bp->rss_conf_obj.udp_rss_v6 = udp_rss_requested;
 			DP(BNX2X_MSG_ETHTOOL,
-			   "rss re-configured, UDP 4-tupple %s\n",
+			   "rss re-configured, UDP 4-tuple %s\n",
 			   udp_rss_requested ? "enabled" : "disabled");
 			if (bp->state == BNX2X_STATE_OPEN)
 				return bnx2x_rss(bp, &bp->rss_conf_obj, false,
@@ -3437,7 +3437,7 @@  static int bnx2x_set_rss_flags(struct bnx2x *bp, struct ethtool_rxnfc *info)
 
 	case IPV4_FLOW:
 	case IPV6_FLOW:
 		/* For IP only 2-tupple hash is supported */
 		if (info->data ^ (RXH_IP_SRC | RXH_IP_DST)) {
 			DP(BNX2X_MSG_ETHTOOL,
 			   "Command parameters not supported\n");
@@ -3388,7 +3388,7 @@  static int bnx2x_set_rss_flags(struct bnx2x *bp, struct ethtool_rxnfc *info)
 	case TCP_V4_FLOW:
 	case TCP_V6_FLOW:
-		/* For TCP only 4-tupple hash is supported */
+		/* For TCP only 4-tuple hash is supported */
 		if (info->data ^ (RXH_IP_SRC | RXH_IP_DST |
 				  RXH_L4_B_0_1 | RXH_L4_B_2_3)) {
@@ -3399,7 +3399,7 @@  static int bnx2x_set_rss_flags(struct bnx2x *bp, struct ethtool_rxnfc *info)
 	case UDP_V4_FLOW:
 	case UDP_V6_FLOW:
-		/* For UDP either 2-tupple hash or 4-tupple hash is supported */
+		/* For UDP either 2-tuple hash or 4-tuple hash is supported */
 		if (info->data == (RXH_IP_SRC | RXH_IP_DST |
 				   RXH_L4_B_0_1 | RXH_L4_B_2_3))
@@ -3437,7 +3437,7 @@  static int bnx2x_set_rss_flags(struct bnx2x *bp, struct ethtool_rxnfc *info)
 	case IPV4_FLOW:
 	case IPV6_FLOW:
-		/* For IP only 2-tupple hash is supported */
+		/* For IP only 2-tuple hash is supported */
 		if (info->data ^ (RXH_IP_SRC | RXH_IP_DST)) {
 			DP(BNX2X_MSG_ETHTOOL,